<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
  <context>
    <name>StartPage</name>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="42"/>
      <source>Start</source>
      <translation>Pradėti</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="43"/>
      <source>Documents</source>
      <translation>Dokumentai</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="44"/>
      <source>Help</source>
      <translation>Žinynas</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="45"/>
      <source>Activity</source>
      <translation>Veiklos</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="46"/>
      <source>Recent files</source>
      <translation>Paskiausiai naudoti failai</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="47"/>
      <source>Tip</source>
      <translation>Patarimas</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="48"/>
      <source>Adjust the number of recent files to be shown here in menu Edit -&gt; Preferences -&gt; General -&gt; Size of recent file list</source>
      <translation>Keiskite čia rodomų paskiausių rinkmenų skaičių pasirinkę Taisa -&gt; Nuostatos -&gt; Bendrosios -&gt; Paskiausiai naudotų rinkmenų sąrašo ilgis</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="49"/>
      <source>Examples</source>
      <translation>Pavyzdžiai</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="50"/>
      <source>General documentation</source>
      <translation>Pagrindinė dokumentacija</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="51"/>
      <source>User hub</source>
      <translation>Vartotojų centras</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="52"/>
      <source>This section contains documentation useful for FreeCAD users in general: a list of all the workbenches, detailed instructions on how to install and use the FreeCAD application, tutorials, and all you need to get started.</source>
      <translation>Šiame skyriuje talpinama „FreeCad“ vartotojams bendrai naudingos žinios: visų darbastalių sąrašas, išsamūs nurodymai, kaip įdiegti ir naudoti „FreeCAD“ programą, pamokymus ir visa kita, ko jums prireiktų pradedant.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="53"/>
      <source>Power users hub</source>
      <translation>Pažengusių vartotojų centras</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="54"/>
      <source>This section gathers documentation for advanced users and people interested in writing python scripts. You will also find there a repository of macros, instructions on how to install and use them, and more information about customizing FreeCAD to your specific needs.</source>
      <translation>Šiame skyriuje surinktos žinios pažengusiems vartotojams ir tiems, kuriuos domina „python“ kalba rašytos programėlės. Čia taip pat rasite makrokomandų talpyklą, paaiškinimus, kaip jas įsidiegti ir naudoti bei dar daug gerų patarimų, kaip pritaikyti „FreeCAD“ prie jūsų ypatingų poreikių.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
      <source>Developers hub</source>
      <translation>Kūrėjų centras</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
      <source>This section contains material for developers: How to compile FreeCAD yourself, how the FreeCAD source code is structured + how to navigate in it, how to develop new workbenches and/or embed FreeCAD in your own application.</source>
      <translation>Šis skyrius skirtas kūrėjams: Čia galima rasti, kaip pačiam sukompiliuoti „FreeCAD“, kaip sudarytas programos kodas ir kaip jį žvalgyti, kaip sukurti naujus darbastalius ir/arba įterpti juos į jūsų nuosavą programą.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="57"/>
      <source>Manual</source>
      <translation>Vartotojo vadovas</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="58"/>
      <source>The FreeCAD manual is another, more linear way to present the information contained in this wiki. It is made to be read like a book, and will gently introduce you to many other pages from the hubs above. &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;e-book versions&lt;/a&gt; are also available.</source>
      <translation>„FreeCAD“ vartotojo vadovas yra kitas, nuosekliu būdu pateikiantis žinias, kurios sudaro šį wiki žinyną. Jis parašytas skaitymui, panašiam į įprastinės knygos skaitymą ir sklandžiai supažindins su daugeliu kitų puslapių, pateikiamų vartotojų centruose. Taip pat pasiekiama ir &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;angliška el. knyga&lt;/a&gt;.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="59"/>
      <source>Workbenches documentation</source>
      <translation>Darbastalių vadovai</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="60"/>
      <source>These are the help pages of all the workbenches currently installed on this computer.</source>
      <translation>Čia yra visų šiuo metu kompiuteryje įdiegtų darbastalių žinynai.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="61"/>
      <source>Getting help from the community</source>
      <translation>Gauti pagalbos iš bendruomenės</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="62"/>
      <source>The &lt;a href="http://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt; is a great place to get help from other FreeCAD users and developers. The forum has many sections for different types of issues and discussion subjects. If in doubt, post in the more general &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Help on using FreeCAD&lt;/a&gt; section.</source>
      <translation>&lt;a href="http://forum.freecadweb.org"&gt;„FreeCAD“ forumas&lt;/a&gt;yra puiki vieta gauti pagalbos iš kitų programos naudotojų ir kūrėjų. Forume rasite daug skilčių įvairiausioms bėdoms ar temoms aptrarti. Jei esate pasimetę, į kurią skiltį kreiptis, palikite įrašą bendresnėje skiltyje &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Pagalba, kaip naudoti „FreeCAD“&lt;/a&gt;.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="63"/>
      <source>If it is the first time you are posting on the forum, be sure to &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;read the guidelines&lt;/a&gt; first!</source>
      <translation>Jei tai pirmas kartas, kai skelbiate įrašą forume, pirmiausia primigtynai siūlome perskaityti &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;įrašų skelbimo patarimus&lt;/a&gt;!</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="64"/>
      <source>FreeCAD also maintains a public &lt;a href="https://www.freecadweb.org/tracker"&gt;bug tracker&lt;/a&gt; where anybody can submit bugs and propose new features. To avoid causing extra work and give the best chances to see your bug solved, make sure you read the &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;bug submission guide&lt;/a&gt; before posting.</source>
      <translation>„FreeCAD“ taip pat prižiūri viešą &lt;a href="https://www.freecadweb.org/tracker"&gt;žinomų klaidų sąrašą&lt;/a&gt;, kur kiekvienas gali pranešti apie rastas klaidas ar pasiūlyti naujas programos ypatybes. Kad išvengtumėte papildomo darbo ir suteiktumėte geriausias galimybes pamatyti savo klaidą išspręstą, prieš pranešdami apie ją būtinai perskaitykite &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;patarimus, kaip pranešti apie klaidas&lt;/a&gt;.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="65"/>
      <source>Available addons</source>
      <translation>Pasiekiami plėtiniai</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="66"/>
      <source>Below is a list of available extra workbenches that can be added to your FreeCAD installation. Browse and install them from menu Tools -&gt; Addons manager. You can learn more about any of them by clicking the links below.</source>
      <translation>Žemiau pateiktas papildomų darbastalių, kurie gali būti įdiegti į jūsų „FreeCAD“ programą, sąrašas. Naršykite ir įdiekite juos meniu (Įrankiai-&gt;Plėtinių valdyklė) pagalba. Sužinoti plačiau apie kiekvieną jų galite paspaudę nuorodas, esančias žemiau.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="67"/>
      <source>If not bundled with your FreeCAD version, install the FreeCAD documentation package to get documentation hubs, workbench help and individual command documentation without an internet connection.</source>
      <translation>Jei nepridėta kartu su jūsų „FreeCAD“ laida, įsidiekite programos žinyną, kad turėtumėte po ranka išsamų darbastalių ir paskirų komandų žinyną ir neprisijungus prie žiniatinklio.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="68"/>
      <source>Cannot fetch information from GitHub. &lt;a href="EnableDownload.py"&gt;Authorize FreeCAD to access the internet&lt;/a&gt; and reload the Start page.</source>
      <translation>Negalima paimti duomenų iš „GitHub“. &lt;a href="EnableDownload.py"&gt;Suteikite „FreeCAD“ prieigą prie interneto&lt;/a&gt;ir iš naujo įkelkite Pradžios puslapį.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="69"/>
      <source>Recent commits</source>
      <translation>Paskiausi keitimai</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="70"/>
      <source>Below are the latest changes added to the &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;FreeCAD source code&lt;/a&gt;. These changes might not reflect yet in the FreeCAD version that you are currently running. Check the &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;available options&lt;/a&gt; if you wish to obtain a development version.</source>
      <translation>Žemiau pateikti vėliausi atnaujinimai &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;„FreeCAD“ išeities tekstuose&lt;/a&gt;. Šie atnaujinimai gali dar neatsispindėti jūsų dabartinėje „FreeCAD“ programos laidoje. Patikrinkite &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;siūlomų laidų parinktis&lt;/a&gt;, jei norite gauti programos plėtros laidą.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
      <source>See all commits on github</source>
      <translation>Žiūrėti visas programos laidas „github“ svetainėje</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
      <source>You can configure a custom folder to display here in menu Edit -&gt; Preferences -&gt; Start -&gt; Show additional folder</source>
      <translation>Galite nustatyti kad pasirinktinis aplankas būtų rodomas čia. Tam eikite į Taisa-&gt;Nuostatos-&gt;Pradžia-&gt;Rodyti papildomą aplanką</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="73"/>
      <source>version</source>
      <translation>laida</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="74"/>
      <source>build</source>
      <translation>sukurti</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="75"/>
      <source>Create new...</source>
      <translation>Sukurti naują...</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="76"/>
      <source>Unknown</source>
      <translation>Nežinoma</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="77"/>
      <source>Forum</source>
      <translation>Diskusijos</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="78"/>
      <source>The latest posts on the &lt;a href="https://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt;:</source>
      <translation>Naujausi &lt;a href="https://forum.freecadweb.org"&gt;„FreeCAD“ forumo&lt;/a&gt; įrašai:</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="79"/>
      <source>To open any of the links above in your desktop browser, Right-click -&gt; Open in external browser</source>
      <translation>Kad atverti bet kurią nuorodą jūsų naršyklėje, spauskite dešinį pelės mygtuką ir pasirinkite „Atverti išorinėje naršyklėje“</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="80"/>
      <source>Creation date</source>
      <translation>Sukūrimo data</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="81"/>
      <source>Last modification</source>
      <translation>Paskutinis pakeitimas</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
      <source>Notes</source>
      <translation>Pastabos</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
      <source>Open start page preferences</source>
      <translation type="unfinished">Open start page preferences</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <location filename="../../Workbench.cpp" line="65"/>
      <source>Start page</source>
      <translation>Pradžios puslapis</translation>
    </message>
  </context>
  <context>
    <name>CmdStartPage</name>
    <message>
      <location filename="../../Command.cpp" line="44"/>
      <source>Start</source>
      <translation>Pradėti</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="45"/>
      <source>Start Page</source>
      <translation>Pradžios puslapis</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Displays the start page in a browser view</source>
      <translation>Atvaizduoja pradžios puslapį naršyklės rodinyje</translation>
    </message>
  </context>
  <context>
    <name>DlgStartPreferences</name>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="14"/>
      <source>Start page options</source>
      <translation>Pradžios puslapio parinktys</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="20"/>
      <source>Start page template</source>
      <translation>Pradžios puslapio šablonas</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="26"/>
      <source>An optional HTML template that will be used instead of the default start page.</source>
      <translation>Pasirinktinis HTML šablonas, kuris bus naudojamas vietoj įprastinio Pradžios puslapio.</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="42"/>
      <source>Contents</source>
      <translation>Turinys</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="48"/>
      <source>Show forum</source>
      <translation>Rodyti forumą</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="55"/>
      <source>Show examples folder contents</source>
      <translation>Rodyti pavyzdžių aplankų turinį</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="62"/>
      <source>Show additional folder</source>
      <translation>Rodyti papildomą aplanką</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="69"/>
      <source>If you want the examples to show on the first page</source>
      <translation>Jei norite pavyzdžių, rodomų Pradžios puslapyje</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="91"/>
      <source>If this is checked, the latest posts from the FreeCAD forum will be displayed on the Activity tab</source>
      <translation>Jei tai pasirinkta, naujausi „FreeCAD“ forumo įrašai bus rodomi Veiklos skirtuke</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="110"/>
      <source>An optional custom folder to be displayed at the bottom of the first page</source>
      <translation>Pasirinktinis aplankas, rodomas Pradžios puslapio apačioje</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="126"/>
      <source>Show notepad</source>
      <translation>Rodyti užrašinę</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="133"/>
      <source>Shows a notepad next to the file thumbnails, where you can keep notes across FreeCAD sessions</source>
      <translation>Rodo užrašinės turinį šalia rinkmenos paveikslėlio, kur galite palikti pastabas tarp „FreeCAD“ sesijų</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="155"/>
      <source>Fonts and colors</source>
      <translation>Šriftai ir spalvos</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="167"/>
      <source>The background of the main start page area</source>
      <translation>Pagrindinio pradžios puslapio srities pagrindo spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="187"/>
      <source>Background color</source>
      <translation>Pagrindo spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="199"/>
      <source>in FreeCAD</source>
      <translation>„FreeCAD“ programoje</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="218"/>
      <source>In external browser</source>
      <translation>Išorinėje naršyklėje</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="236"/>
      <source>Background color gradient down</source>
      <translation>Pagrindo apačios spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="249"/>
      <source>The color of the version text</source>
      <translation>Laidos aprašo spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="269"/>
      <source>Link color</source>
      <translation>Nuorodos spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="276"/>
      <source>An optional image to display as background</source>
      <translation>Pasirinktinis paveikslas, atvaizduotinas kaip pagrindo vaizdas</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="289"/>
      <source>If this is checked, if a style sheet is specified in General preferences, it will be used and override the colors below</source>
      <translation>Jei tai pasirinkta, esant nurodytam stiliui Pagrindinėse nuostatose, jis bus naudojamas pakeisti žemiau esančias spalvas</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="308"/>
      <source>Page background color</source>
      <translation>Puslapio pagrindo spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="321"/>
      <source>The color of the text on the main pages</source>
      <translation>Pagrindinių puslapių rašto spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="341"/>
      <source>Background image</source>
      <translation>Pagrindo paveikslėlis</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="348"/>
      <source>Page text color</source>
      <translation>Puslapio rašto spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="361"/>
      <source>The color of the links</source>
      <translation>Nuorodų spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="387"/>
      <source>The background color of the boxes inside the pages</source>
      <translation>Langų puslapių viduje pagrindo spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="407"/>
      <source>Box background color</source>
      <translation>Lango pagrindo spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="420"/>
      <source>The background color behind the panels</source>
      <translation>Pagrindo spalva už skydelių</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="449"/>
      <source>The down gradient for the background color (currently unsupported)</source>
      <translation>Apatinė pagrindo spalvokaitos spalva (kol kas nepalaikoma)</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="472"/>
      <source>Open links</source>
      <translation>Atverti saitus</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="479"/>
      <source>Background text color</source>
      <translation>Pagrindo rašto spalva</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="486"/>
      <source>Use FreeCAD style sheet</source>
      <translation>Naudoti „FreeCAD“ išvaizdos stilių</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="493"/>
      <source>Font family</source>
      <translation>Šriftų šeima</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="502"/>
      <source>The font family to use on the start page. Can be a font name or a comma-separated series of fallback fonts</source>
      <translation>Šriftų šeima, naudojama pradžios puslapyje. Gali būti nurodytas vieno šrifto pavadinimas arba nurodyti keli kableliais atskirti pakaitiniais šriftai</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="508"/>
      <source>Arial,Helvetica,sans</source>
      <translation>Arial,Helvetica,sans</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="521"/>
      <source>The base font size to use for all texts of the Start page</source>
      <translation>Pagrindinio šrifto dydis pradžios puslapio rašto rodymui</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="524"/>
      <source>px</source>
      <translation> tšk.</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="542"/>
      <source>Use gradient for New File icon</source>
      <translation>Naudoti pereinamas spalvas Naujos rinkmenos paveikslėliui</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="568"/>
      <source>Options</source>
      <translation>Parinktys</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="577"/>
      <source>Should the start page be closed after loading?</source>
      <translation>Ar pradžios puslapis turi būti užvertas po programos paleidimo?</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="596"/>
      <source>Switch workbench after loading</source>
      <translation>Po paleidimo persijungti į darbastalį</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="603"/>
      <source>Close start page after loading</source>
      <translation>Po paleidimo užverti pradžios puslapį</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="610"/>
      <source>Close &amp; switch on file open</source>
      <translation>Užverti ir persijungti, kai atveriama rinkmena</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="617"/>
      <source>If FreeCAD is started by opening a file, apply the two settings above</source>
      <translation>Jei „FreeCAD“ yra paleidžiama atveriant rinkmeną, pasirinkite dvi aukščiau esančias parinktis</translation>
    </message>
  </context>
</TS>
